translate.convert.xliff2oo.oofilteroptions

Package translate :: Package convert :: Module xliff2oo :: Class oofilteroptions |
[hide private]
[frames] | no frames]

# Class oofilteroptions

source code

Class Variables | [hide private]
| error = ``[``'``variables``'``,` `'``xmltags``'``,` `'``escapes``'``]``
| warning = ``[``'``blank``'``]``
| alwayswarn = `True` hash(x)
| limitfilters = ``[``'``variables``'``,` `'``xmltags``'``,` `'``escapes``'``,` `'``blank``'``]``
| excludefilters = ``{``}``
| includefuzzy = `False` hash(x)
| includereview = `False` hash(x)
| autocorrect = `False` hash(x)